<h1 align="center">tldream</h1>
<p align="center">A tiny little diffusion drawing app</p>

![A screenshot of the tldream web app](https://github.com/Sanster/tldream-frontend/blob/tldream/assets/tldream.png)

```bash
pip install tldream
tldream --device cuda
```